package com.gree.mall.contest.controller.mini.goods;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.gree.mall.contest.bean.goods.*;
import com.gree.mall.contest.bean.user.UserWxBean;
import com.gree.mall.contest.controller.pc.goods.CategoryLogic;
import com.gree.mall.contest.enums.QrCodeEnum;
import com.gree.mall.contest.exception.RemoteServiceException;
import com.gree.mall.contest.helper.ResponseHelper;
import com.gree.mall.contest.logic.common.WechatLogic;
import com.gree.mall.contest.logic.goods.GoodsLogic;
import com.gree.mall.contest.logic.user.UserLogic;
import com.gree.mall.contest.plus.entity.Goods;
import com.gree.mall.contest.plus.entity.GoodsCategory;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.List;

@Slf4j
@RestController
@Tag(name = "商品列表", description = "商品列表")
@RequestMapping(value = "/mini/goods", produces = "application/json; charset=utf-8")
@RequiredArgsConstructor
public class MiniGoodsController {
    private final GoodsLogic goodsLogic;
    private final UserLogic userLogic;
    private final CategoryLogic categoryLogic;
    private final WechatLogic wechatLogic;


    @GetMapping("/category/list/all")
    @Operation(summary = "分类列表(树形)")
    public ResponseHelper<List<CategoryBean>> category(HttpServletRequest request) throws Exception {
        List<CategoryBean> categoryBeans = categoryLogic.queryAll(request);
        return ResponseHelper.success(categoryBeans);
    }

    @GetMapping("/category/list/first")
    @Operation(summary = "获取一级分类列表")
    public ResponseHelper<List<GoodsCategory>> categoryFirst(HttpServletRequest request) throws Exception {
        List<GoodsCategory> categoryBeans = categoryLogic.queryFirst(request);
        return ResponseHelper.success(categoryBeans);
    }

    @GetMapping("/category/list/second")
    @Operation(summary = "获取二级分类列表")
    public ResponseHelper<List<GoodsCategory>> categorySecond(
            HttpServletRequest request,
            @Parameter(description = "一级分类id", required = true) @RequestParam(required = true) String categoryId
    ) throws Exception {
        List<GoodsCategory> categoryBeans = categoryLogic.querySecond(request, categoryId);
        return ResponseHelper.success(categoryBeans);
    }


    @GetMapping("/category/list")
    @Operation(summary = "分类列表")
    public ResponseHelper<List<GoodsCategory>> category(
            HttpServletRequest request,
            @Parameter(description = "分类id", required = false) @RequestParam(required = false) String parentId,
            @Parameter(description = "分类名称", required = false) @RequestParam(required = false) String name
    ) throws Exception {
        List<GoodsCategory> list = categoryLogic.list(request, parentId, name);
        return ResponseHelper.success(list);
    }

    @GetMapping("/list/level1")
    @Operation(summary = "根据一级分类查询商品列表")
    public ResponseHelper<IPage<Goods>> listByLevel1(
            HttpServletRequest request,
            @Parameter(description = "一级分类id", required = true) @RequestParam(required = true) String categoryId,
            @Parameter(description = "页号", required = true) @RequestParam Integer pageNum,
            @Parameter(description = "页大小", required = true) @RequestParam Integer pageSize
    ) throws Exception {
        IPage<Goods> categoryGoodBeans = categoryLogic.categoryGoodsList(request, categoryId, pageNum, pageSize);
        return ResponseHelper.success(categoryGoodBeans);
    }


    @GetMapping("/list/sort/page")
    @Operation(summary = "商品列表")
    public ResponseHelper<IPage<GoodsNewBean>> page(
            HttpServletRequest request,
            @Parameter(description = "商品关键字") @RequestParam(required = false) String keyword,
            @Parameter(description = "排序 0=综合 1=销量 2=价格升 3=价格降 4=上新") @RequestParam(required = false, defaultValue = "0") Integer sort,
            @Parameter(description = "分类id") @RequestParam(required = false) String categoryId,
            @Parameter(description = "页号", required = true) @RequestParam Integer pageNum,
            @Parameter(description = "页大小", required = true) @RequestParam Integer pageSize
    ) throws Exception {
        IPage<GoodsNewBean> page = goodsLogic.miniPage(request, keyword, categoryId, sort, pageNum, pageSize);
        return ResponseHelper.success(page);
    }

    @GetMapping("/detail")
    @Operation(summary = "商品详情")
    public ResponseHelper<GoodsBean> detail(
            HttpServletRequest request,
            @Parameter(description = "id", required = true) @RequestParam String goodsId,
            @Parameter(description = "userId", required = true) @RequestParam String userId,
            @Parameter(description = "wxSceneId", required = false) @RequestParam(required = false) String wxSceneId
    ) throws RemoteServiceException {
        GoodsBean detail = goodsLogic.miniDetail(request, goodsId, userId, wxSceneId);
        return ResponseHelper.success(detail);
    }

    @GetMapping("/qrcode")
    @Operation(summary = "获取商品二维码")
    public ResponseHelper<String> qrcode(
            @Parameter(description = "用户id", required = true) @RequestParam String userId,
            @Parameter(description = "商品id", required = true) @RequestParam String goodsId,
            HttpServletRequest request
    ) throws IOException, RemoteServiceException {
        UserWxBean userWxBean = userLogic.userDetail(userId, request);
        String qrcode = wechatLogic.getQrcode(QrCodeEnum.GOODS.toString().toLowerCase(), goodsId, userId, userWxBean.getCompanyWechatId());
        return ResponseHelper.success(qrcode);
    }

    @GetMapping("/promotion/group/list")
    @Operation(summary = "团购商品列表")
    public ResponseHelper<IPage<PromotionGoodsBean>> grouplist(
            @Parameter(description = "用户id", required = true) @RequestParam String userId,
            @Parameter(description = "商品类型id", required = false) @RequestParam(required = false) String goodsCategoryId,
            @Parameter(description = "搜索内容", required = false) @RequestParam(required = false) String keyword,
            @Parameter(description = "页号", required = true) @RequestParam(required = true) Integer pageNo,
            @Parameter(description = "页大小", required = true) @RequestParam(required = true) Integer pageSize,
            HttpServletRequest request
    ) throws IOException, RemoteServiceException {
        IPage<PromotionGoodsBean> promotionGoodsBeanIPage = goodsLogic.myGroupGoods(userId, goodsCategoryId, keyword, pageNo, pageSize, request);
        return ResponseHelper.success(promotionGoodsBeanIPage);
    }

    @GetMapping("/promotion/share/qrcode")
    @Operation(summary = "团购活动分享二维码")
    public ResponseHelper<PromotionShareQrCode> shareQrcode(
            @Parameter(description = "用户id", required = true) @RequestParam String userId,
            HttpServletRequest request
    ) throws IOException {
        PromotionShareQrCode promotionShareQrCode = goodsLogic.queryShareQrcode(userId, request);
        return ResponseHelper.success(promotionShareQrCode);
    }


    @PostMapping("/cut")
    @Operation(summary = "让利二维码或链接")
    public ResponseHelper<String> cut(
            @RequestBody List<CutGoodsBean> cutGoodsBeans,
            HttpServletRequest request
    ) throws IOException {
        String cutQrcode = goodsLogic.getCutQrcode(cutGoodsBeans, request);
        return ResponseHelper.success(cutQrcode);
    }

    @GetMapping("/package/choice")
    @Operation(summary = "团购商品-选购列表")
    public ResponseHelper<List<List<GoodsPackageBean>>> choicePackage(
            @Parameter(description = "套购商品id", required = true) @RequestParam String goodsId,
            HttpServletRequest request
    ) throws IOException {
        List<List<GoodsPackageBean>> lists = goodsLogic.choicePackage(goodsId, request);
        return ResponseHelper.success(lists);
    }

}
